summaryrefslogtreecommitdiffstats
path: root/generic/tkPanedWindow.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tkPanedWindow.c')
-rw-r--r--generic/tkPanedWindow.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/generic/tkPanedWindow.c b/generic/tkPanedWindow.c
index c0385af..07000c3 100644
--- a/generic/tkPanedWindow.c
+++ b/generic/tkPanedWindow.c
@@ -12,7 +12,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tkPanedWindow.c,v 1.13.2.3 2003/07/18 09:53:16 dkf Exp $
+ * RCS: @(#) $Id: tkPanedWindow.c,v 1.13.2.4 2003/08/19 21:00:13 jenglish Exp $
*/
#include "tkPort.h"
@@ -1224,7 +1224,7 @@ PanedWindowWorldChanged(instanceData)
/*
* Allocated a graphics context for drawing the paned window widget
* elements (background, sashes, etc.).
*/
gcValues.background = Tk_3DBorderColor(pwPtr->background)->pixel;
@@ -1233,6 +1233,7 @@ PanedWindowWorldChanged(instanceData)
Tk_FreeGC(pwPtr->display, pwPtr->gc);
}
pwPtr->gc = newGC;
+ Tk_SetWindowBackground(pwPtr->tkwin, gcValues.background);
/*
* Issue geometry size requests to Tk.
@@ -1224,7 +1224,7 @@ PanedWindowWorldChanged(instanceData)
/*
* Allocated a graphics context for drawing the paned window widget
- * elements (background, sashes, etc.).
+ * elements (background, sashes, etc.) and set the window background.
*/
gcValues.background = Tk_3DBorderColor(pwPtr->background)->pixel;